<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it" sourcelanguage="en">
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Seleziona la lingua dell&apos;applicazione:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Lingua di sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Note</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Per favore è necessario riavviare l&apos;applicazione affinché il cambio di lingua abbia effetto.</translation>
    </message>
</context>
<context>
    <name>Report</name>
    <message>
        <source>Time Sheet Report</source>
        <translation>Rapporto ore lavorate</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Company:</source>
        <translation>Ditta:</translation>
    </message>
    <message>
        <source>Address:</source>
        <translation>Indirizzo:</translation>
    </message>
    <message>
        <source>Phone:</source>
        <translation>Telefono:</translation>
    </message>
    <message>
        <source>Fax:</source>
        <translation>Fax:</translation>
    </message>
    <message>
        <source>Email:</source>
        <translation>Email:</translation>
    </message>
    <message>
        <source>Website:</source>
        <translation>Sito web:</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Prepend currency symbol</source>
        <translation>Anteponi simbolo valuta</translation>
    </message>
    <message>
        <source>Hourly rate:</source>
        <translation>Tasso orario:</translation>
    </message>
    <message>
        <source>Tax rate:</source>
        <translation>percentuale di tasse:</translation>
    </message>
    <message>
        <source>Currency symbol:</source>
        <translation>Simbolo valuta:</translation>
    </message>
    <message>
        <source>Contact Information</source>
        <translation>Informazioni contatto</translation>
    </message>
    <message>
        <source>Data</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Anteprima</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Stampa</translation>
    </message>
    <message>
        <source>Web Page (*.html *.htm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iCalendar (*.ics)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Outlook CSV (*.csv)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View Reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Phone: %1</source>
        <translation>Telefono: %1</translation>
    </message>
    <message>
        <source>Fax: %1</source>
        <translation>Fax: %1</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Ore</translation>
    </message>
    <message>
        <source>Subtotal</source>
        <translation>Subtotale</translation>
    </message>
    <message>
        <source>Taxes</source>
        <translation>Tasse</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Totale</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation>
            <numerusform>%n ora</numerusform>
            <numerusform>%n ore</numerusform>
        </translation>
    </message>
    <message>
        <source>%L1 hours</source>
        <translation>%L1 ore</translation>
    </message>
</context>
<context>
    <name>SessionDelegate</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">Errore</translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionDialog</name>
    <message>
        <source>Add Session</source>
        <translation>Aggiungi sessione</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Data:</translation>
    </message>
    <message>
        <source>Start:</source>
        <translation>Inizio:</translation>
    </message>
    <message>
        <source>Stop:</source>
        <translation>Fine:</translation>
    </message>
    <message>
        <source>Task:</source>
        <translation>Compito:</translation>
    </message>
    <message>
        <source>Edit Session</source>
        <translation>Modifica sessione</translation>
    </message>
</context>
<context>
    <name>SessionModel</name>
    <message>
        <source>Total</source>
        <translation type="unfinished">Totale</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished">Inizio</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished">Fine</translation>
    </message>
    <message>
        <source>Task</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hours</source>
        <translation type="unfinished">Ore</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>00:00:00</source>
        <translation>00:00:00</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Inizio</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Fine</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Project</source>
        <translation>&amp;Progetto</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Aggiungi</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Rimuovi</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Session</source>
        <translation>&amp;Sessione</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Modifica</translation>
    </message>
    <message>
        <source>Ctrl+Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>S&amp;ettings</source>
        <translation>&amp;Impostazioni</translation>
    </message>
    <message>
        <source>Columns</source>
        <translation>Colonne</translation>
    </message>
    <message>
        <source>&amp;Decimal Totals</source>
        <translation>Totali &amp;Decimali</translation>
    </message>
    <message>
        <source>&amp;Inline Editing</source>
        <translation>&amp;Modifica in linea</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Lingua...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;A proposito</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>A proposito delle &amp;Qt</translation>
    </message>
    <message>
        <source>Project</source>
        <translation>Progetto</translation>
    </message>
    <message>
        <source>Timer</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Show all</source>
        <translation>Mostra tutto</translation>
    </message>
    <message>
        <source>Show only unbilled</source>
        <translation>Mostra solo occorrenze non fatturate</translation>
    </message>
    <message>
        <source>Show only this year</source>
        <translation>Mostra solo occorrenze di quest&apos;anno</translation>
    </message>
    <message>
        <source>Show only this month</source>
        <translation>Mostra solo occorrenze di questo mese</translation>
    </message>
    <message>
        <source>Show only this week</source>
        <translation>Mostra solo occorrenze di questa settimana</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read time data.</source>
        <translation>Impossibile leggere i dati relativi alla temporizzazione</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Senza titolo</translation>
    </message>
    <message>
        <source>Unable to write time data.</source>
        <translation>Impossibile leggere i dati relativi alla temporizzazione.</translation>
    </message>
    <message>
        <source>There are timers running. Stop timers and quit?</source>
        <translation>Ci sono dei timer in esecuzione. Fermare i timer e chiudere l&apos;applicazione?</translation>
    </message>
    <message>
        <source>About</source>
        <translation>A proposito</translation>
    </message>
    <message>
        <source>A program to help track spent time</source>
        <translation>Un programma per aiutarvi a tenere traccia del tempo speso</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Domande</translation>
    </message>
    <message>
        <source>&amp;Create Report...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View R&amp;eports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel this session?</source>
        <translation>Cancella questa sessione?</translation>
    </message>
    <message>
        <source>Add Project</source>
        <translation>Aggiungi Progetto</translation>
    </message>
    <message>
        <source>Enter project name:</source>
        <translation>Inserisci nome progetto:</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>Unable to create time data location.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to move time data location.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A project with that name already exists.</source>
        <translation>Un progetto con quel nome esiste già.</translation>
    </message>
    <message>
        <source>Remove selected project?</source>
        <translation>Rimuovi il progetto selezionato?</translation>
    </message>
    <message>
        <source>Remove selected session?</source>
        <translation>Rimuovi la sessione selezionata?</translation>
    </message>
    <message numerus="yes">
        <source>%n timer(s) running</source>
        <translation>
            <numerusform>%n orologio partito</numerusform>
            <numerusform>%n orologi partito</numerusform>
        </translation>
    </message>
    <message>
        <source>Kapow Punch Clock</source>
        <translation>Kapow Punch Clock</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Punch clock program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Store settings as INI format in specified file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not create automatic backups of time data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The time data file to use.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
